@@ -18,31 +18,31 @@
 #' @export
 
 military <- function(year = NULL, ...) {
+    if (is.null(year)) {
+        year <- getOption("tigris_year", 2024)
 
-  if (is.null(year)) {
+        message(sprintf("Retrieving data for the year %s", year))
+    }
 
-    year <- getOption("tigris_year", 2022)
+    if (year < 2011) {
+        fname <- as.character(match.call())[[1]]
 
-    message(sprintf("Retrieving data for the year %s", year))
+        msg <- sprintf(
+            "%s is not currently available for years prior to 2011.  To request this feature,
+                   file an issue at https://github.com/walkerke/tigris.",
+            fname
+        )
 
-  }
+        stop(msg, call. = FALSE)
+    }
 
-  if (year < 2011) {
-
-    fname <- as.character(match.call())[[1]]
-
-    msg <- sprintf("%s is not currently available for years prior to 2011.  To request this feature,
-                   file an issue at https://github.com/walkerke/tigris.", fname)
-
-    stop(msg, call. = FALSE)
-
-  }
-
-  url <- sprintf("https://www2.census.gov/geo/tiger/TIGER%s/MIL/tl_%s_us_mil.zip",
-                 as.character(year), as.character(year))
-
-  return(load_tiger(url, tigris_type = "military", ...))
+    url <- sprintf(
+        "https://www2.census.gov/geo/tiger/TIGER%s/MIL/tl_%s_us_mil.zip",
+        as.character(year),
+        as.character(year)
+    )
 
+    return(load_tiger(url, tigris_type = "military", ...))
 }
 
 
@@ -76,42 +76,48 @@ military <- function(year = NULL, ...) {
 #' @inheritSection load_tiger_doc_template Additional Arguments
 #' @export
 landmarks <- function(state, type = "point", year = NULL, ...) {
+    if (is.null(year)) {
+        year <- getOption("tigris_year", 2024)
 
-  if (is.null(year)) {
+        message(sprintf("Retrieving data for the year %s", year))
+    }
 
-    year <- getOption("tigris_year", 2022)
+    if (year < 2011) {
+        fname <- as.character(match.call())[[1]]
 
-    message(sprintf("Retrieving data for the year %s", year))
+        msg <- sprintf(
+            "%s is not currently available for years prior to 2011.  To request this feature,
+                   file an issue at https://github.com/walkerke/tigris.",
+            fname
+        )
 
-  }
+        stop(msg, call. = FALSE)
+    }
 
-  if (year < 2011) {
+    state <- validate_state(state)
 
-    fname <- as.character(match.call())[[1]]
-
-    msg <- sprintf("%s is not currently available for years prior to 2011.  To request this feature,
-                   file an issue at https://github.com/walkerke/tigris.", fname)
-
-    stop(msg, call. = FALSE)
-
-  }
-
-  state <- validate_state(state)
-
-  cyear <- as.character(year)
-
-  if (type == "area") {
-    url <- sprintf("https://www2.census.gov/geo/tiger/TIGER%s/AREALM/tl_%s_%s_arealm.zip",
-                   cyear, cyear, state)
-    return(load_tiger(url, tigris_type = "area_landmark", ...))
-
-  } else if (type == "point") {
-    url <- sprintf("https://www2.census.gov/geo/tiger/TIGER%s/POINTLM/tl_%s_%s_pointlm.zip",
-                  cyear, cyear, state)
-    return(load_tiger(url, tigris_type = "point_landmark", ...))
-
-  } else {
-    stop('The argument supplied to type must be either "point" or "area"', call. = FALSE)
-  }
+    cyear <- as.character(year)
 
+    if (type == "area") {
+        url <- sprintf(
+            "https://www2.census.gov/geo/tiger/TIGER%s/AREALM/tl_%s_%s_arealm.zip",
+            cyear,
+            cyear,
+            state
+        )
+        return(load_tiger(url, tigris_type = "area_landmark", ...))
+    } else if (type == "point") {
+        url <- sprintf(
+            "https://www2.census.gov/geo/tiger/TIGER%s/POINTLM/tl_%s_%s_pointlm.zip",
+            cyear,
+            cyear,
+            state
+        )
+        return(load_tiger(url, tigris_type = "point_landmark", ...))
+    } else {
+        stop(
+            'The argument supplied to type must be either "point" or "area"',
+            call. = FALSE
+        )
+    }
 }
